Package: fsdaR
Title: Robust Data Analysis Through Monitoring and Dynamic
        Visualization
Version: 0.9-1
VersionNote: Released 0.9-0 on 2023-12-06 on CRAN
Authors@R: c(person("Valentin", "Todorov", role = c("aut", "cre"), email = "valentin.todorov@chello.at", comment=c(ORCID = "0000-0003-4215-0245"))
         , person("Emmanuele", "Sordini", role = "aut", email = "Emmanuele.sordini@ec.europa.eu")
         , person("Aldo", "Corbellini", role = "ctb")
         , person("Francesca", "Torti", role = "ctb")
         , person("Marco",  "Riani", role = "ctb")
         , person("Domenico", "Perrotta", role = "ctb")
         , person("Andrea", "Cerioli", role = "ctb")
          )
Description: Provides interface to the 'MATLAB' toolbox 'Flexible Statistical Data Analysis
    (FSDA)' which is comprehensive and computationally efficient
    software package for robust statistics in regression, multivariate
    and categorical data analysis. The current R version implements tools
    for regression: (forward search, S- and MM-estimation, least trimmed
    squares (LTS) and least median of squares (LMS)), for multivariate analysis
    (forward search, S- and MM-estimation), for cluster analysis and cluster-wise regression.
    The distinctive feature of our package is the possibility of
    monitoring the statistics of interest as a function of breakdown point,
    efficiency or subset size, depending on the estimator. This is
    accompanied by a rich set of graphical features, such as dynamic
    brushing, linking, particularly useful for exploratory data analysis.
Depends: R (>= 3.5.0)
Imports: rJava, methods, stats4, ggplot2
Suggests: robustbase, rrcov, MASS
Encoding: UTF-8
SystemRequirements: (license-free) MATLAB Runtime (MCR) V 9.12, Java
        (>=8)
LazyLoad: yes
LazyData: yes
License: GPL (>= 3)
URL: https://github.com/UniprJRC/fsdaR
BugReports: https://github.com/UniprJRC/fsdaR/issues
Packaged: 2026-05-19 21:58:43 UTC; valen
Author: Valentin Todorov [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4215-0245>),
  Emmanuele Sordini [aut],
  Aldo Corbellini [ctb],
  Francesca Torti [ctb],
  Marco Riani [ctb],
  Domenico Perrotta [ctb],
  Andrea Cerioli [ctb]
Maintainer: Valentin Todorov <valentin.todorov@chello.at>
NeedsCompilation: no
Repository: CRAN
RoxygenNote: 7.3.3
Date/Publication: 2026-05-19 22:20:02 UTC
Built: R 4.5.2; ; 2026-05-19 23:50:55 UTC; unix
